%% please cite
% Angione*, Pratanwanich*, Li
% "A hybrid of metabolic flux analysis and Bayesian factor modeling for multi-omic temporal pathway activation"
% ACS Synthetic Biology, 2015

%% 
% Claudio Angione - 2015 


format long
addpath(genpath('C:\Program Files\MATLAB\R2014a\toolbox\cobra'));
initCobraToolbox

if (matlabpool('size') == 0)  %opens only if it is closed 
    matlabpool('open','local',4)
end
addAttachedFiles(gcp,{'glpk.m','glpkcc'});  %adds these files to the independent workers of the parallel pool






%data_only = load('norm_test_data.mat');
%data_only = data_only.norm_test_data;
%data_only = xlsread('data_only.xlsx','normalizzati');



load('iJO1366_Ecoli_ac.mat');
%load('iJO1366_Ecoli_suc.mat');
%load('iJO1366_Ecoli_BDO.mat');
%load('iJO1366_Ecoli_bio_suc_ac.mat');

load('geni.mat');
load('reaction_expression.mat');
load('probe_genes.mat');
load('glucose.mat');
load('oxygen.mat');
load('name_conditions_with_replicates.mat');
load('name_conditions.mat');
if evalin('base','exist(''data_only'',''var'')')==0
    load('data_only.mat');
end
load('gene_variances.mat');
load('oxygen_without_replicates.mat');
load('glucose_without_replicates.mat');
load('indices_dynamical_conditions.mat');




max_gene_importance = 10000;



%%
%this and the following instruction find the locations of the gene 'bXXXX'
%(genes in the fbamodel) in the array probe_genes (sequence f genes appearing in the
%microarray data available)

posizione_gene = cell(length(geni),1);

for i=1:length(geni)
    matches = strfind(probe_genes,geni{i});     
    posizione_gene{i} = find(~cellfun('isempty', matches));
end


%% 
num_dynamical_conditions = length(indices_dynamical_conditions)

points = zeros(num_dynamical_conditions,2);     %table of points coordinates. The number of points is equal to the number of conditions in the microarray data
gene_importance = zeros(length(geni),1);    %array of the coefficients indicating gene importance. The size is equal to the number of genes in the model


%gene_importance = 10 * ones(1,length(geni));

min_var = min(gene_variances);
probe_gene_importance = max_gene_importance * 1./(gene_variances/min_var);  %this way the importance of a gene can range from  0 to max_gene_importance


for i=1:length(geni)
    if isempty(posizione_gene{i})
        gene_importance(i) = max_gene_importance/2;
    else
        gene_importance(i) = probe_gene_importance(posizione_gene{i});
    end
    
end

% OLD CODE (NOT PARALLEL)
% for num_cond = 1 : size(data_only,2)
%     microarray_data = data_only(:,num_cond);    %import only the num_cond column
%     output = process_conditions(microarray_data, num_cond, geni, posizione_gene, fbamodel, oxygen, glucose, reaction_expression, gene_importance);
%     points(num_cond,1) = output(1);
%     points(num_cond,2) = output(2);
%    disp(num_cond);
% end


% NEW PARALLEL CODE
points = zeros(num_dynamical_conditions,2);
fluxes = zeros (length(reaction_expression),num_dynamical_conditions);


% cond_index_in_replicates = zeros(num_dynamical_conditions,1);
% 
% for i = 1 : num_dynamical_conditions
%     index_cond = dynamical_indices(i);
%     IndexC = strfind(name_conditions_with_replicates, name_conditions{index_cond});
%     Index = find(not(cellfun('isempty', IndexC)));      %in order to map each of the 466 real conditions to the 907 conditions with replicates (for which we have oxygen and glucose arrays), these instructions find the locations in name_conditions_with_replicates where there is the substring name_conditions{num_cond}. Then we will take the oxygen and glucose of the first of the location found (which are always replicates of the same experimental condition, so oxygen and glucose are the same across the replicates)
%     Index = Index(1);
%     cond_index_in_replicates(i) = Index;
% end
% 
% oxygen_without_replicates = oxygen(cond_index_in_replicates);
% glucose_without_replicates = glucose(cond_index_in_replicates);

% emptyIndex = cellfun(@isempty,glucose_without_replicates);       %# Find indices of empty cells
% glucose_without_replicates(emptyIndex) = {'10'};                    %# Fill empty cells with 10, the standard glucose uptake (as done in process_conditions)
% glucose_without_replicates = str2double(glucose_without_replicates);  %# Convert the cell array

aux_points =  cell(num_dynamical_conditions,1);
aux_fluxes =  cell(num_dynamical_conditions,1);

parfor_progress(num_dynamical_conditions); % Initialize
%parfor
parfor i = 1 : num_dynamical_conditions
    index_cond = indices_dynamical_conditions(i);
    microarray_data = data_only(:,index_cond);    %import only the num_cond column
    [v1, out] =  process_conditions(microarray_data, index_cond, geni, posizione_gene, fbamodel, oxygen_without_replicates, glucose_without_replicates, reaction_expression, gene_importance);  %it's necessary to pass the original fbamodel that will be changed in the subfunction (oxygen will be put to zero or not according to the anaerobic or aerobic condition, the default condition in fbamodel is aerobic)
    %points(i,:) = out;
    %fluxes(:,i) = v1;
    aux_points{i} = out;
    aux_fluxes{i} = v1;
    disp(i);
    parfor_progress;
end

for i = 1 : num_dynamical_conditions
    points(i,:) = aux_points{i};
    fluxes(:,i) = aux_fluxes{i};
end

stringa=['points_dynamic']; 
save(stringa, 'points');

stringa=['fluxes_dynamic']; 
save(stringa, 'fluxes');

num_cond = size(points,1)/4;
spacedist_cond = zeros(num_cond,1);

for i = 1:num_cond;
    j = 4*(i-1);
    spacedist_cond(i) = pdist(points(j+1:j+2,:))  + pdist(points(j+2:j+3,:)) + pdist(points(j+3:j+4,:));
end


%see plot_conditions for plotting
