load('name_conditions_with_replicates.mat');
load('name_conditions.mat');
load('oxygen.mat');
load('glucose.mat');
load('indices_dynamical_conditions.mat');
load('points_dynamic__gene_importance_10000.mat');


convert_index = zeros(length(name_conditions),1);   %converts index without replicates (466 conditions) to the equivalent index of the condition with replicates (907 conditions)

for i=1:length(name_conditions)
    IndexC = strfind(name_conditions_with_replicates, name_conditions{i});
    Index = find(not(cellfun('isempty', IndexC)));      %in order to map each of the 466 real conditions to the 907 conditions with replicates (for which we have oxygen and glucose arrays), these instructions find the locations in name_conditions_with_replicates where there is the substring name_conditions{num_cond}. Then we will take the oxygen and glucose of the first of the location found (which are always replicates of the same experimental condition, so oxygen and glucose are the same across the replicates)
    Index = Index(1);
    convert_index(i) = Index;
    
end

oxygen_without_replicates = oxygen(convert_index);
glucose_without_replicates = glucose(convert_index);


emptyIndex = cellfun(@isempty,glucose_without_replicates);       %# Find indices of empty cells
glucose_without_replicates(emptyIndex) = {'10'};                    %# Fill empty cells with 10, the standard glucose uptake (as done in process_conditions)
glucose_without_replicates = str2double(glucose_without_replicates);  %# Convert the cell array


glucose_dynamical = glucose_without_replicates(indices_dynamical_conditions);
oxygen_dynamical = oxygen_without_replicates(indices_dynamical_conditions);

index_aerobic = find(strcmp(oxygen_dynamical, 'aerobic'));
index_anaerobic = find(strcmp(oxygen_dynamical, 'anaerobic'));


x=points(index_aerobic,1);
y=points(index_aerobic,2);
%z=points(index_aerobic,3);


% C = glucose_dynamical(index_aerobic);
% p1 = scatter(-x,-y,40,C,'x')
% p1 = scatter3(-x,-y,-z,40,C,'x')
% %set(gcf,'renderer','OpenGL')  %lets my laptop handle the graphics, rather than leaving it to MATLAB. This will be changed again later to export high quality pictures
% colormap(jet(256)) 
% colorbar;


%colors = colormap(hsv(length(x)));
colors = distinguishable_colors(length(x)/4); %generate maximally perceptually-distinct colors

%ha = tight_subplot(4,10,[.04 .03],[.1 .01],[.06 .01]) 
high_variation_indices = [];


fig1 = figure(1);
linestyles={'--','-','-.'};

for i = 1:4:length(x)
    if max(abs(y(i:i+3))) < 0.1     %plot only points with low value of second objective
        %plot3(-x(i),-y(i),-z(i),'o','Color',colors((i+3)/4,:));
        plot(x(i),y(i),'o','Color',colors((i+3)/4,:));
        hold on
        %plot3(-x(i:i+3),-y(i:i+3),-z(i:i+3),'Color',colors((i+3)/4,:),'LineStyle',linestyles{randi(3)},'Marker','.', 'LineWidth',1);
        plot(x(i:i+3),y(i:i+3),'Color',colors((i+3)/4,:),'LineStyle',linestyles{randi(3)},'Marker','.', 'LineWidth',1);
        %
        
        %arrow([-x(i) -y(i) -z(i)],[-x(i+1) -y(i+1) -z(i+1)], 'Length',5, 'EdgeColor','r','MarkerFaceColor','r')
        %arrow([-x(i+1) -y(i+1) -z(i+1)],[-x(i+2) -y(i+2) -z(i+2)], 'Length',5, 'EdgeColor','r','MarkerFaceColor','r')
        %arrow([-x(i+2) -y(i+2) -z(i+2)],[-x(i+3) -y(i+3) -z(i+3)], 'Length',5, 'EdgeColor','r')
    else
        high_variation_indices(end+1) = i;
    end
    hold on
end

grid on

xlabel('Biomass [h^{-1}]');
ylabel('Acetate [mmolh^{-1}gDW^{-1}]');
%zlabel('Acetate [mmolh^{-1}gDW^{-1}]');


%fig2pdf3d(gca, 'figura', 'movie15', 'pdflatex')



fig2 = fig1;



fig3 = figure(3);

for i = 1:length(high_variation_indices)
        real_ind = high_variation_indices(i);
        %plot3(-x(i),-y(i),-z(i),'o','Color',colors((i+3)/4,:),'LineStyle',linestyles{randi(3)});
        plot(x(real_ind),y(real_ind),'o','Color',colors((real_ind+3)/4,:),'LineStyle',linestyles{randi(3)});
        hold on
        %plot3(-x(i:i+3),-y(i:i+3),-z(i:i+3),'.-','Color',colors((i+3)/4,:));
        plot(x(real_ind:real_ind+3),y(real_ind:real_ind+3),'.-','Color',colors((real_ind+3)/4,:),'LineStyle',linestyles{randi(3)});
        hold on
end


fig4 = figure(4);

x=points(index_anaerobic,1);
y=points(index_anaerobic,2);
%z=points(index_anaerobic,3);

for i = 1:4:length(x)
    %plot3(-x(i:i+3),-y(i:i+3),-z(i:i+3),'.-')
    plot(x(i:i+3),y(i:i+3),'.-')
    hold on
end


% 
% C = glucose_dynamical(index_anaerobic);
% %p2 = scatter(-x,-y,40,C,'o')
% p2 = scatter3(-x,-y,-z,70,C,'o')
% %set(gcf,'renderer','OpenGL')  %lets my laptop handle the graphics, rather than leaving it to MATLAB. This will be changed again later to export high quality pictures
% colormap(jet(256));
% colormap(flipud(colormap));
% colorbar;

legend('aerobic','anaerobic');
legend('Location','NorthWest');
grid on

xlabel('Biomass [h^{-1}]');
ylabel('Acetate [mmolh^{-1}gDW^{-1}]');
%zlabel('Acetate [mmolh^{-1}gDW^{-1}]');
%title('466 conditions')

set(gcf,'renderer','painters')  %to export high quality eps or pdf

aux = xlim;
xlim([0 aux(2)]);




[h_m h_i]=inset(fig2,fig1);







fig6 = figure(6);
clf
x=points(:,1);
y=points(:,2);
colors = distinguishable_colors(length(x)/4); %generate maximally perceptually-distinct colors

% Plot concentrations as a function of time
clf
plot_rows = 7;
plot_columns = ceil((length(x)/4)/plot_rows);   %the +2 is needed for the plot of Biomass and for the last subplot which is reserved for the list of antibiotics given day bay day

    
%figure; subplot1(3, 2, 'Gap', [.01 .03], 'XTickL', 'Margin', 'YTickL', 'Margin');
    

name_dynamical_conditions = cell(length(x)/4,1);

make_it_tight = true;
subplot = @(m,n,p) subtightplot (m, n, p, [0.01 0.02], 0.1, [0.1 0.01]);
if ~make_it_tight,  clear subplot;  end

for i = 1:4:length(x)
    ix_plot = ceil(i/4);
    subplot(plot_rows,plot_columns,ix_plot);
    %subaxis(plot_rows,plot_columns,ix_plot, 'Spacing', 0.03, 'Padding', 0, 'Margin', 0);
    plot(x(i),y(i),'o','Color',colors((i+3)/4,:),'MarkerSize', 4);
    hold on
    plot(x(i+3),y(i+3),'*','Color',colors((i+3)/4,:), 'MarkerSize', 3);
    plot(x(i+1),y(i+1),'+','Color',colors((i+3)/4,:), 'MarkerSize', 2);
    plot(x(i+2),y(i+2),'+','Color',colors((i+3)/4,:), 'MarkerSize', 2);
    plot(x(i:i+3),y(i:i+3),'Color',colors((i+3)/4,:),  'LineWidth',0.8);
    %axis tight
    xlim([0 1.5]);
    set(gca, 'XTick', (0: 0.3: 1.5) );
    if (ceil(ix_plot/plot_columns) < plot_rows) && (ix_plot ~= plot_columns*(plot_rows-1) )% which means the plot is not in the last row && not the last of the last column (correction needed because the very last boxplot is actually empty
        set(gca,'xticklabel',[])
    end
    ylim([0 14.9]);
    set(gca, 'YTick', (0 : 3 : 15) );
    text_leg = name_conditions{indices_dynamical_conditions(i+1)}; %we take the name of the second time step (out of 4) because its name is usually ore indicative of the condition, because the first time step has been taken as a wild type or some standard name (see the dynamical_conditions.xls file)
    text_leg = strrep(text_leg,'_t150','');
    text_leg = strrep(text_leg,'_t180','');
    text_leg = strrep(text_leg,'_t300','');
    text_leg = strrep(text_leg,'_1min','');
    text_leg = strrep(text_leg,'_5min','');
    text_leg = strrep(text_leg,'_4hr','');
    text_leg = strrep(text_leg,'_minus5min','');
    text_leg = strrep(text_leg,'_7hr','');
    text_leg = strrep(text_leg,'_t1','');
    text_leg = strrep(text_leg,'_t30','');
    text_leg = strrep(text_leg,'_T3','');
    text_leg = strrep(text_leg,'_t2','');
    text_leg = strrep(text_leg,'_t0','');
   
    %leg = legend(text_leg, 'location','northoutside'); 
%     leg = legend(text_leg, 'location','southwest'); 
%     set(leg, 'Interpreter', 'none'); %avoids the latex interpreter in the legend
%     legend boxoff 
%     text_in_legend = findobj(leg,'type','line','linestyle','-');
%     set(text_in_legend,'visible','off');
    
    text_leg = [num2str(ix_plot) '. ' text_leg];
    t = text(0.05,1.5,text_leg);
    name_dynamical_conditions{ix_plot} = text_leg;
    set(t, 'Interpreter', 'none');
    grid off;
    
    
% 

% 
 set(gca, ...
   'Box'         , 'off'     , ...
   'TickDir'     , 'out'     , ...
   'TickLength'  , [.02 .02] , ...
   'XMinorTick'  , 'on'      , ...
   'YMinorTick'  , 'on'      , ...
   'XGrid'       , 'off'      , ...
   'YGrid'       , 'on'      , ...
      'LineWidth'   , 1         );
%   'XColor'      , [.3 .3 .3], ...
%   'YColor'      , [.3 .3 .3], ...
%   'YTick'       , 0:500:2500, ...

end


ylab = ylabel('Acetate [mmol h^{-1} gDW^{-1}]', 'position',[-7.15 50], 'FontSize'   , 10);  % requires manual posistioning
xlab = xlabel('Biomass [h^{-1}]', 'position',[-1.7 -4], 'FontSize'   , 10);



subplot(plot_rows,plot_columns,plot_rows*plot_columns);
axis off;
text(0.4,0.5,'\circ start');
text(0.4,0.3,'+ intermediate');
text(0.4,0.1,'* end');

%set(gca, 'fontName', 'Times New Roman'); 
%set(findall(gcf,'type','XTickLabel'),'fontName','Times New Roman','fontSize',11)
%set(findall(gcf,'type','YTickLabel'),'fontName','Times New Roman','fontSize',11)
%set(findall(gcf,'type','text'),'fontName','Times New Roman','fontSize',11)


%% plot the four conditions (28th - aerobic, 29th - anaerobic, 26th - high glucose, 27th - low glucose) considered by Ploy IN A SINGLE LINE HORIZONTALLY
figure;

make_it_tight = false;
subplot = @(m,n,p) subtightplot (m, n, p, [0.005 0.02], 0.1, [0.1 0.01]);
if ~make_it_tight,  clear subplot;  end

plot_rows = 1;
plot_columns = 4;
j = 0;
color_set = cell(1,4);
color_set{1} = 'red';
color_set{2} = 'blue';
color_set{3} = 'green'; 
color_set{4} = 'magenta';
for i = [28*4-3 29*4-3 26*4-3 27*4-3]
    j=j+1;
    subplot(plot_rows,plot_columns,j);
    %subaxis(plot_rows,plot_columns,ix_plot, 'Spacing', 0.03, 'Padding', 0, 'Margin', 0);
    plot(x(i),y(i),'o','Color',color_set{j}, 'MarkerSize',4);
    hold on
    plot(x(i+1),y(i+1),'+','Color',color_set{j}, 'MarkerSize', 2);
    plot(x(i+2),y(i+2),'+','Color',color_set{j}, 'MarkerSize', 2);
    plot(x(i+3),y(i+3),'*','Color',color_set{j}, 'MarkerSize',3);
    plot(x(i:i+3),y(i:i+3),'Color',color_set{j},'Marker','.', 'MarkerSize',1, 'LineWidth',1);
    %axis tight
    xlim([0 1.5]);
    set(gca, 'XTick', (0: 0.3: 1.5) );
    if (ceil(ix_plot/plot_columns) < plot_rows) && (ix_plot ~= plot_columns*(plot_rows-1) )% which means the plot is not in the last row && not the last of the last column (correction needed because the very last boxplot is actually empty
        set(gca,'xticklabel',[])
    end
    ylim([0 14.9]);
    set(gca, 'YTick', (0 : 3 : 15) );
    text_leg = name_conditions{indices_dynamical_conditions(i+1)}; %we take the name of the second time step (out of 4) because its name is usually ore indicative of the condition, because the first time step has been taken as a wild type or some standard name (see the dynamical_conditions.xls file)
    text_leg = strrep(text_leg,'_t150','');
    text_leg = strrep(text_leg,'_t180','');
    text_leg = strrep(text_leg,'_t300','');
    text_leg = strrep(text_leg,'_1min','');
    text_leg = strrep(text_leg,'_5min','');
    text_leg = strrep(text_leg,'_4hr','');
    text_leg = strrep(text_leg,'_minus5min','');
    text_leg = strrep(text_leg,'_7hr','');
    text_leg = strrep(text_leg,'_t1','');
    text_leg = strrep(text_leg,'_t30','');
    text_leg = strrep(text_leg,'_T3','');
    text_leg = strrep(text_leg,'_t2','');
    text_leg = strrep(text_leg,'_t0','');
   
    %leg = legend(text_leg, 'location','northoutside'); 
%     leg = legend(text_leg, 'location','southwest'); 
%     set(leg, 'Interpreter', 'none'); %avoids the latex interpreter in the legend
%     legend boxoff 
%     text_in_legend = findobj(leg,'type','line','linestyle','-');
%     set(text_in_legend,'visible','off');
    t = text(0.05,1.5,text_leg);
    name_dynamical_conditions{ix_plot} = text_leg;
    set(t, 'Interpreter', 'none');
    grid off;
   
    
 set(gca, ...
   'Box'         , 'off'     , ...
   'TickDir'     , 'out'     , ...
   'TickLength'  , [.02 .02] , ...
   'XMinorTick'  , 'on'      , ...
   'YMinorTick'  , 'on'      , ...
   'XGrid'       , 'off'      , ...
   'YGrid'       , 'on'      , ...
      'LineWidth'   , 1         );
%   'XColor'      , [.3 .3 .3], ...
%   'YColor'      , [.3 .3 .3], ...
%   'YTick'       , 0:500:2500, ...

end

ylab = ylabel('Acetate [mmol h^{-1} gDW^{-1}]', 'position',[-6.15 6.8], 'FontSize'   , 10);  % requires manual posistioning
xlab = xlabel('Biomass [h^{-1}]', 'position',[-2.4 -2.5], 'FontSize'   , 10);


%% BARPLOT OF SPACEDIST_COND (see barplotcond for a color plot, because the following one is single color only)

% figure;
% width = 0.5;
% barh(flipud(spacedist_cond),width);
% ylim([1 41]);  %because there are 41 barplots and they are plotted starting automatically from 1 and not from 0
% NumTicks = 41;
% L = get(gca,'YLim');
% set(gca,'YTick',linspace(L(1),L(2),NumTicks))
% set(gca,'YTickLabel',flipud(name_dynamical_conditions));

barplotcond;

%colormapeditor
%exportfig(gcf, 'figura.pdf', 'color', 'cmyk', 'Width', '30', 'Height', '20', 'FontMode', 'scaled', 'FontSize', '0.9' );
